@@ -42,7 +42,7 @@ class Gateway(gateway_base.BaseGateway):
         )
 
     def exit(self):
-        """ trigger gateway exit.  Defer waiting for finishing
+        """trigger gateway exit.  Defer waiting for finishing
         of receiver-thread and subprocess activity to when
         group.terminate() is called.
         """
@@ -75,7 +75,10 @@ class Gateway(gateway_base.BaseGateway):
         """ return some sys/env information from remote. """
         if update or not hasattr(self, "_cache_rinfo"):
             ch = self.remote_exec(rinfo_source)
-            self._cache_rinfo = RInfo(ch.receive())
+            try:
+                self._cache_rinfo = RInfo(ch.receive())
+            finally:
+                ch.waitclose()
         return self._cache_rinfo
 
     def hasreceiver(self):
@@ -93,20 +96,20 @@ class Gateway(gateway_base.BaseGateway):
         return RemoteStatus(statusdict)
 
     def remote_exec(self, source, **kwargs):
-        """ return channel object and connect it to a remote
-            execution thread where the given ``source`` executes.
+        """return channel object and connect it to a remote
+        execution thread where the given ``source`` executes.
 
-            * ``source`` is a string: execute source string remotely
-              with a ``channel`` put into the global namespace.
-            * ``source`` is a pure function: serialize source and
-              call function with ``**kwargs``, adding a
-              ``channel`` object to the keyword arguments.
-            * ``source`` is a pure module: execute source of module
-              with a ``channel`` in its global namespace
+        * ``source`` is a string: execute source string remotely
+          with a ``channel`` put into the global namespace.
+        * ``source`` is a pure function: serialize source and
+          call function with ``**kwargs``, adding a
+          ``channel`` object to the keyword arguments.
+        * ``source`` is a pure module: execute source of module
+          with a ``channel`` in its global namespace
 
-            In all cases the binding ``__name__='__channelexec__'``
-            will be available in the global namespace of the remotely
-            executing code.
+        In all cases the binding ``__name__='__channelexec__'``
+        will be available in the global namespace of the remotely
+        executing code.
         """
         call_name = None
         file_name = None
